==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Klinkut");
define("_BROWSERS","Prohlee");
define("_OPERATINGSYS","Operan systmy");
define("_UNKNOWN","Neznm");
define("_OTHER","Jin / Neznm");
define("_MISCSTATS","Veobecn statistika");
define("_REGUSERS","Registrovan uivatel:");
define("_ACTIVEAUTHORS","Aktivn autoi:");
define("_STORIESPUBLISHED","Publikovan lnky:");
define("_SACTIVETOPICS","Aktivn tmata:");
define("_COMMENTSPOSTED","Poslan komente:");
define("_SSPECIALSECT","Speciln sekce:");
define("_ARTICLESSEC","lnky ve spec. sekci:");
define("_LINKSINLINKS","Odkazy v databzi:");
define("_LINKSCAT","Kategorie odkaz:");
define("_NEWSWAITING","Zprvy ekajc na publikovn:");
define("_NUKEVERSION","Verze PHP-Nuke:");
define("_SEARCHENGINES","Vyhledvae");
define("_BOTS","Robots/Spiders");
define("_STATS","statistika pstup");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-czech.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Klinkut");
define("_BROWSERS","Prohlee");
define("_OPERATINGSYS","Operan systmy");
define("_UNKNOWN","Neznm");
define("_OTHER","Jin / Neznm");
define("_MISCSTATS","Veobecn statistika");
define("_REGUSERS","Registrovan uivatel:");
define("_ACTIVEAUTHORS","Aktivn autoi:");
define("_STORIESPUBLISHED","Publikovan lnky:");
define("_SACTIVETOPICS","Aktivn tmata:");
define("_COMMENTSPOSTED","Poslan komente:");
define("_SSPECIALSECT","Speciln sekce:");
define("_ARTICLESSEC","lnky ve spec. sekci:");
define("_LINKSINLINKS","Odkazy v databzi:");
define("_LINKSCAT","Kategorie odkaz:");
define("_NEWSWAITING","Zprvy ekajc na publikovn:");
define("_NUKEVERSION","Verze PHP-Nuke:");
define("_SEARCHENGINES","Vyhledvae");
define("_BOTS","Robots/Spiders");
define("_STATS","statistika pstup");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>
